% Input: timeSeries
% Output: matrix, each row is of format:
% {[enterTime, exitTime, succeed/failure]}
% [conditions x 161 x 3 + 170]


function x = instantPip170_1(timeSeries,BuyorSell,sl,tp, exit_on_close)
    
    % get number of rows
     length= size(timeSeries,1);

     tp_counter = 0;
     sl_counter = 0;
       
    % get values
    open = timeSeries(:,1);
    high = timeSeries(:,2);
    low = timeSeries(:,3);
    close = timeSeries(:,4);  
    
    VWAP=(open+close+(high+low)/2)/3;
 
    price = close;
    
    % Bolinger bands
    
    upBol_1 = timeSeries(:,5);
    lwBol_1 = timeSeries(:,6);
    upBol_15 = timeSeries(:,7);
    lwBol_15 = timeSeries(:,8);
    upBol_20 = timeSeries(:,9);
    lwBol_20 = timeSeries(:,10);
    upBol_25 = timeSeries(:,11);
    lwBol_25 = timeSeries(:,12);
    upBol_30 = timeSeries(:,13);
    lwBol_30 = timeSeries(:,14);    

    % RSIs
    
    RSI8  = timeSeries(:,15);
    RSI14  = timeSeries(:,16);
    RSI50  = timeSeries(:,17);
    RSI200  = timeSeries(:,18);
    
    % CCIs
    
    CCI5  = timeSeries(:,19);
    CCI10  = timeSeries(:,20);
    CCI21  = timeSeries(:,21);
    CCI35  = timeSeries(:,22);
    
    % DPOs
    
    DPO10 = timeSeries(:,23);
    DPO20 = timeSeries(:,24);
    DPO50 = timeSeries(:,25);
    DPO200 = timeSeries(:,26);
    
    % stochastics

    stochK143 = timeSeries(:,27);
    stochD143 = timeSeries(:,28);
    
    stochK215 = timeSeries(:,29);
    stochD215 = timeSeries(:,30);
    
    stochK3610 = timeSeries(:,31);
    stochD3610 = timeSeries(:,32);
    
    stochK5021 = timeSeries(:,33);
    stochD5021 = timeSeries(:,34);
    
% Moving averages    
    
    MA5 = timeSeries(:,35);
    MA15 = timeSeries(:,36);
    MA30 = timeSeries(:,37);
    MA70 = timeSeries(:,38);
    MA150 = timeSeries(:,39);
    
    EMA10 = timeSeries(:,40);
    EMA20 = timeSeries(:,41);
    EMA50 = timeSeries(:,42);
    EMA100 = timeSeries(:,43);
    EMA200 = timeSeries(:,44); 
    
    m = timeSeries(:,45);
    d = timeSeries(:,46);
    h = timeSeries(:,47);
    mn = timeSeries(:,48);
    day = timeSeries(:,49);
    
    lag1 = timeSeries(:,50);
    lag2 = timeSeries(:,51);
    lag3 = timeSeries(:,52);
    lag4 = timeSeries(:,53);
    lag5 = timeSeries(:,54);
    lag6 = timeSeries(:,55);
    
    NUM_COND = 170;   % number of conditions
    
    trades = [];
    condValue = []; % number of conditions satisfied at t
    
    for t=1:length 
        
        cond = zeros(1,NUM_COND);
        
        % Bolinger bands
        
        cond(1) = within(upBol_1(t),price(t)); % within 5 pips of upper Bollinger band
        cond(2) = within(upBol_15(t),price(t)); % within 5 pips of upper Bollinger band
        cond(3) = within(upBol_20(t),price(t)); % within 5 pips of upper Bollinger band
        cond(4) = within(upBol_25(t),price(t)); % within 5 pips of upper Bollinger band
        cond(5) = within(upBol_30(t),price(t)); % within 5 pips of upper Bollinger band
        
        cond(6) = within(lwBol_1(t),price(t)); % within 5 pips of upper Bollinger band
        cond(7) = within(lwBol_15(t),price(t)); % within 5 pips of upper Bollinger band
        cond(8) = within(lwBol_20(t),price(t)); % within 5 pips of upper Bollinger band
        cond(9) = within(lwBol_25(t),price(t)); % within 5 pips of upper Bollinger band
        cond(10) = within(lwBol_30(t),price(t)); % within 5 pips of upper Bollinger band
                
        cond(11) = upBol_1(t)/price(t);
        cond(12) = lwBol_1(t)/price(t);
        cond(13) = upBol_15(t)/price(t);
        cond(14) = lwBol_15(t)/price(t);
        cond(15) = upBol_20(t)/price(t);
        cond(16) = lwBol_20(t)/price(t);
        cond(17) = upBol_25(t)/price(t);
        cond(18) = lwBol_25(t)/price(t);
        cond(19) = upBol_30(t)/price(t);
        cond(20) = lwBol_30(t)/price(t);
       
        % Price trend
        
        cond(21) = trend(price,t,'DOWN',2); % duration 2 bars
        cond(22) = trend(price,t,'DOWN',3); % duration 3 bars
        cond(23) = trend(price,t,'DOWN',4); % duration 4 bars
        cond(24) = trend(price,t,'DOWN',5); % duration 5 bars
        cond(25) = trend(price,t,'DOWN',6); % duration 6 bars
        
        cond(26) = trend(price,t,'UP',2); % duration 2 bars
        cond(27) = trend(price,t,'UP',3); % duration 3 bars
        cond(28) = trend(price,t,'UP',4); % duration 4 bars
        cond(29) = trend(price,t,'UP',5); % duration 5 bars
        cond(30) = trend(price,t,'UP',6); % duration 6 bars
        
        if t > 2
        cond(31) = high(t) < high(t-1) && low(t) < low(t-1);
        cond(32) = high(t) < high(t-1) && low(t) > low(t-1);
        cond(33) = high(t) > high(t-1) && low(t) < low(t-1); 
        cond(34) = high(t) > high(t-1) && low(t) > low(t-1); 
        end
        
        cond(35) = price(t) / open(t);
        
        % RSI
        
        cond(36) = trend(RSI8,t,'DOWN',2);
        cond(37) = trend(RSI8,t,'DOWN',3);
        cond(38) = trend(RSI8,t,'DOWN',4);
        cond(39) = trend(RSI8,t,'DOWN',5);
        cond(40) = trend(RSI8,t,'DOWN',6);
        
        cond(41) = trend(RSI8,t,'UP',2);
        cond(42) = trend(RSI8,t,'UP',3);
        cond(43) = trend(RSI8,t,'UP',4);
        cond(44) = trend(RSI8,t,'UP',5);
        cond(45) = trend(RSI8,t,'UP',6);
        
        cond(46) = trend(RSI14,t,'DOWN',2);
        cond(47) = trend(RSI14,t,'DOWN',3);
        cond(48) = trend(RSI14,t,'DOWN',4);
        cond(49) = trend(RSI14,t,'DOWN',5);
        cond(50) = trend(RSI14,t,'DOWN',6);
        
        cond(51) = trend(RSI14,t,'UP',2);
        cond(52) = trend(RSI14,t,'UP',3);
        cond(53) = trend(RSI14,t,'UP',4);
        cond(54) = trend(RSI14,t,'UP',5);
        cond(55) = trend(RSI14,t,'UP',6);
        
        cond(56) = trend(RSI50,t,'DOWN',2);
        cond(57) = trend(RSI50,t,'DOWN',3);
        cond(58) = trend(RSI50,t,'DOWN',4);
        cond(59) = trend(RSI50,t,'DOWN',5);
        cond(60) = trend(RSI50,t,'DOWN',6);
        
        cond(61) = trend(RSI50,t,'UP',2);
        cond(62) = trend(RSI50,t,'UP',3);
        cond(63) = trend(RSI50,t,'UP',4);
        cond(64) = trend(RSI50,t,'UP',5);
        cond(65) = trend(RSI50,t,'UP',6);
        
        cond(66) = trend(RSI200,t,'DOWN',2);
        cond(67) = trend(RSI200,t,'DOWN',3);
        cond(68) = trend(RSI200,t,'DOWN',4);
        cond(69) = trend(RSI200,t,'DOWN',5);
        cond(70) = trend(RSI200,t,'DOWN',6);
        
        cond(71) = trend(RSI200,t,'UP',2);
        cond(72) = trend(RSI200,t,'UP',3);
        cond(73) = trend(RSI200,t,'UP',4);
        cond(74) = trend(RSI200,t,'UP',5);
        cond(75) = trend(RSI200,t,'UP',6);
        
        cond(76) = RSI8(t);
        cond(77) = RSI14(t);
        cond(78) = RSI50(t);
        cond(79) = RSI200(t);
        
        % CCI
        
        cond(80) = trend(CCI5,t,'DOWN',2);
        cond(81) = trend(CCI5,t,'DOWN',3);
        cond(82) = trend(CCI5,t,'DOWN',4);
        cond(83) = trend(CCI5,t,'DOWN',5);
        cond(84) = trend(CCI5,t,'DOWN',6);
        
        cond(85) = trend(CCI5,t,'UP',2);
        cond(86) = trend(CCI5,t,'UP',3);
        cond(87) = trend(CCI5,t,'UP',4);
        cond(88) = trend(CCI5,t,'UP',5);
        cond(89) = trend(CCI5,t,'UP',6);
        
        cond(90) = trend(CCI10,t,'DOWN',2);
        cond(91) = trend(CCI10,t,'DOWN',3);
        cond(92) = trend(CCI10,t,'DOWN',4);
        cond(93) = trend(CCI10,t,'DOWN',5);
        cond(94) = trend(CCI10,t,'DOWN',6);
        
        cond(95) = trend(CCI10,t,'UP',2);
        cond(96) = trend(CCI10,t,'UP',3);
        cond(97) = trend(CCI10,t,'UP',4);
        cond(98) = trend(CCI10,t,'UP',5);
        cond(99) = trend(CCI10,t,'UP',6);
        
        cond(100) = trend(CCI21,t,'DOWN',2);
        cond(101) = trend(CCI21,t,'DOWN',3);
        cond(102) = trend(CCI21,t,'DOWN',4);
        cond(103) = trend(CCI21,t,'DOWN',5);
        cond(104) = trend(CCI21,t,'DOWN',6);
        
        cond(105) = trend(CCI21,t,'UP',2);
        cond(106) = trend(CCI21,t,'UP',3);
        cond(107) = trend(CCI21,t,'UP',4);
        cond(108) = trend(CCI21,t,'UP',5);
        cond(109) = trend(CCI21,t,'UP',6);
        
        cond(110) = trend(CCI35,t,'DOWN',2);
        cond(111) = trend(CCI35,t,'DOWN',3);
        cond(112) = trend(CCI35,t,'DOWN',4);
        cond(113) = trend(CCI35,t,'DOWN',5);
        cond(114) = trend(CCI35,t,'DOWN',6);
        
        cond(115) = trend(CCI35,t,'UP',2);
        cond(116) = trend(CCI35,t,'UP',3);
        cond(117) = trend(CCI35,t,'UP',4);
        cond(118) = trend(CCI35,t,'UP',5);
        cond(119) = trend(CCI35,t,'UP',6);
        
        cond(120) = CCI5(t);
        cond(121) = CCI10(t);
        cond(122) = CCI21(t);
        cond(123) = CCI35(t);
        
        % MAs
        
        cond(124) = price(t) / MA5(t);
        cond(125) = price(t) / MA15(t);
        cond(126) = price(t) / MA30(t);
        cond(127) = price(t) / MA70(t);
        cond(128) = price(t) / MA150(t);
        
        cond(129) = price(t) / EMA10(t);
        cond(130) = price(t) / EMA20(t);
        cond(131) = price(t) / EMA50(t);
        cond(132) = price(t) / EMA100(t);
        cond(133) = price(t) / EMA200(t);
        
        if t > 1 cond(134) = VWAP(t) - VWAP(t-1); end
        if t > 2 cond(135) = VWAP(t) - VWAP(t-2); end
        if t > 3 cond(136) = VWAP(t) - VWAP(t-3); end
        if t > 4 cond(137) = VWAP(t) - VWAP(t-4); end
        if t > 5 cond(138) = VWAP(t) - VWAP(t-5); end
        
        if t > 1 cond(139) = VWAP(t) / VWAP(t-1); end
        if t > 2 cond(140) = VWAP(t) / VWAP(t-2); end
        if t > 3 cond(141) = VWAP(t) / VWAP(t-3); end
        if t > 4 cond(142) = VWAP(t) / VWAP(t-4); end
        if t > 5 cond(143) = VWAP(t) / VWAP(t-5); end
        
        % stochastics
        
        cond(144) = stochK143(t);
        cond(145) = stochK215(t);
        cond(146) = stochK3610(t);
        cond(147) = stochK5021(t);
        
        cond(148) = stochD143(t);
        cond(149) = stochD215(t);
        cond(150) = stochD3610(t);
        cond(151) = stochD5021(t);
        
        cond(152) = DPO10(t);
        cond(153) = DPO20(t);
        cond(154) = DPO50(t);
        cond(155) = DPO200(t);
       
        cond(156) = m(t); 
        cond(157) = d(t); 
        cond(158) = h(t); % hour 
        cond(159) = mn(t);% minute
        cond(160) = day(t);
        
        cond(161) = mean(price(1:t))/price(t);
        cond(162) = var(price(1:t));
        cond(163) = mean(VWAP(1:t))/VWAP(t);
        cond(164) = var(VWAP(1:t));
               
        cond(165) = lag1(t);
        cond(166) = lag2(t);
        cond(167) = lag3(t);
        cond(168) = lag4(t);
        cond(169) = lag5(t);
        cond(170) = lag6(t);
      
        condValue = [condValue;cond]; % TODO: next version, keep as vector
        
        [exitTime status ttp_counter ssl_counter] = instantPipExit(t,BuyorSell,sl,tp, exit_on_close);
        
        sl_counter = sl_counter + ssl_counter;
        tp_counter = tp_counter + ttp_counter;
        
        new_row = [t exitTime status];
        
        trades = [trades;new_row];
        
    end
    
    %fprintf('TP was hit %i times \n',tp_counter);
    %fprintf('SL was hit %i times \n',sl_counter);
    
    
x = cell(2);
x{1} = trades;   % n x 3 matrix of trade info (entry time,exit time,status)
x{2} = condValue;% n x 7 matrix of conditions value (0/1)
